"use client";
import React from "react";
import { Strip, StripEvent } from "./component/Strip";
import {
  Button,
  Container,
  createTheme,
  CssBaseline,
  Divider,
  Stack,
  ThemeProvider,
  Typography,
} from "@mui/material";
import { Bus } from "./component/Bus";

function random(min: number, max: number, floor: boolean = true) {
  const value = Math.random() * (max - min + 1) + min;
  return floor ? Math.floor(value) : value;
}

export default function Home() {
  function onStripEvent(event: StripEvent) {
    console.log(event);
  }
  const physicalBuses = 5;
  const virtualBuses = 3;
  const strips = physicalBuses + virtualBuses;
  let clicks = 0;
  let timeout: NodeJS.Timeout | undefined;
  document.body.onclick = (e) => {
    clicks++;
    if (timeout !== undefined) {
      clearTimeout(timeout);
      timeout = undefined;
    }
    timeout = setTimeout(() => (clicks = 0), 500);
    if (clicks < 2) return;
    clearTimeout(timeout);
    clicks = 0;
    console.log(e.target);
    
    e.stopPropagation();
    e.preventDefault();
    if (document.fullscreenElement !== null) document.exitFullscreen();
    else document.body.requestFullscreen({ navigationUI: "hide" });
  
  };

  return (
    <ThemeProvider theme={createTheme({ palette: { mode: "dark" } })}>
      <Container maxWidth="xl" sx={{ height: "100%" }}>
        <div>
          <CssBaseline />
          <Typography variant="h5">Inputs</Typography>
          <Stack direction={"row"}>
            {[...Array(strips)].map((_v, i) => (
              <React.Fragment
                key={`${i < physicalBuses ? "a" : "b"}${
                  i < physicalBuses ? i : i - physicalBuses
                }`}
              >
                {i === physicalBuses ? (
                  <Divider
                    orientation="vertical"
                    variant="middle"
                    sx={{ marginInlineEnd: "15px" }}
                  />
                ) : (
                  ""
                )}
                <Strip
                  onChange={(ev) => onStripEvent(ev)}
                  physicalBuses={physicalBuses}
                  virtualBuses={virtualBuses}
                />
              </React.Fragment>
            ))}
          </Stack>
          <Typography variant="h5">Outputs</Typography>
          <Stack direction={"column"}>
            {[...Array(strips)].map((_v, i) => (
              <React.Fragment
                key={`${i < physicalBuses ? "a" : "b"}${
                  i < physicalBuses ? i : i - physicalBuses
                }`}
              >
                {i === physicalBuses ? (
                  <Divider
                    orientation="vertical"
                    variant="middle"
                    sx={{ margin: "5px" }}
                  />
                ) : (
                  ""
                )}
                <Bus
                  onChange={(ev) => onStripEvent(ev)}
                  physicalBuses={physicalBuses}
                  virtualBuses={virtualBuses}
                />
              </React.Fragment>
            ))}
          </Stack>

          <Button></Button>
        </div>
      </Container>
    </ThemeProvider>
  );
}
